This packaging setup uses mock to build BDR packages from a single spec file
that's shared across all of RHEL5/6/7 and Fedora 19/20.

Mock does builds in clean chroots with only the dependencies and build-depends
actually specified in the package, so "leaked" extra dependencies can't arise.

The spec file and sources are in `unified-rpm`.

All you need to build is a Fedora box and appropriate packages.

There's an EC2 instance i-92bcf9d0 on eu-west-1 that can be used for builds.
It's shut down when not in use. If you want to use the EC2 instance you'll need
to launch it via the EC2 console and check what IP it got, then ssh into
fedora@the.ip.addr. Remember to shut it down / stop it when you're done with
it, it costs 50c/hour to run so if it's running for days that's no fun for
anyone.

QUICKSTART
---

    # Install tools
    yum groupinstall "Development Tools"
    yum install yum-utils rpmdevtools repoview createrepo
    yum-builddep mock
    yum install git svn
    # You only need this to make the postgresql dist tarball
    # because configure has to run:
    yum-builddep postgresql
    # and for the docs in the dist tarball:
    yum install openjade jadetex docbook-dtds docbook5-schemas docbook-style-dsssl docbook-style-xsl

    # Install patched mock
    git clone https://github.com/ringerc/mock.git
    pushd mock
    git checkout target-paths
    ./autogen.sh
    ./configure
    make rpm
    yum install noarch/*
    popd

    # Grab sources and create source tarball
    git clone git://git.postgresql.org/git/postgresql.git
    pushd postgresql
    # whatever bdr you want to build; remember to change the
    # SRPM to match
    git checkout REL9_4_STABLE
    # No need for any options, it's only to create the makefiles
    # for "make dist".
    ./configure
    make dist
    popd

    pushd packaging
    pushd unified-rpm
    mv ../../postgresql/*.bz2 .
    spectool -gf postgresql94.spec
    # If needed, edit unified-rpm/postgresql94.spec, particularly
    # the version defines and the Source0 line for the Pg sources;
    # then:
    popd
    ./mock-build-all.sh

The first run will take longer because it has to set up and cache the mock
chroots.

You can limit the build to only some targets, see the targets variable in
mock-build-all.sh .

If you want to test the packages you built locally, without pushing to a remote
repo, you need only define a repo in yum with the file:// URL to your locally
built repo.

BUILDS
---

See comments on `mock-build-all.sh` for build process.
